==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetFirewallPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property firewallName Firewall resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetFirewallPlainArgs(
    public val firewallName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs =
        com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs.builder()
            .firewallName(firewallName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFirewallPlainArgs].
 */
@PulumiTagMarker
public class GetFirewallPlainArgsBuilder internal constructor() {
    private var firewallName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Firewall resource name
     */
    @JvmName("gnhyagccufonjihg")
    public suspend fun firewallName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.firewallName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("yhufqjspnyngbmsr")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetFirewallPlainArgs = GetFirewallPlainArgs(
        firewallName = firewallName ?: throw PulumiNullFieldException("firewallName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cloudngfw/kotlin/inputs/GetFirewallPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cloudngfw.kotlin.inputs

import com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property firewallName Firewall resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetFirewallPlainArgs(
    public val firewallName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs =
        com.pulumi.azurenative.cloudngfw.inputs.GetFirewallPlainArgs.builder()
            .firewallName(firewallName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetFirewallPlainArgs].
 */
@PulumiTagMarker
public class GetFirewallPlainArgsBuilder internal constructor() {
    private var firewallName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Firewall resource name
     */
    @JvmName("ccgeicawwdifxyfd")
    public suspend fun firewallName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.firewallName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("vcmbvcvwsawfepqe")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetFirewallPlainArgs = GetFirewallPlainArgs(
        firewallName = firewallName ?: throw PulumiNullFieldException("firewallName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
